@@ -47,13 +47,15 @@ shinyUI(fluidPage(
                target = "_blank")),
       span("lets you perform common JavaScript operations in Shiny applications"),
       span("without having to know any JavaScript.")),
-    p("Setup is minimal: this app has been set up to use", strong("shinyjs"),
-      "by simply adding", code("shinyjs::useShinyjs()"), "to the app's", code("ui"), "."),
-    p("After adding this call to your Shiny app, you can",
-      "use the functions provided by", strong("shinyjs"), "as regular intuitive R code."),
-    p("These functions use JavaScript behind the scenes to let you manipulate the",
-      "content (HTML) on the page. These functions should be called from",
-      "the app's", code("server"), "after some user action."),
+    p("You can",
+      "use the functions provided by", strong("shinyjs"), "as regular intuitive R code.",
+      "These functions use JavaScript behind the scenes to let you manipulate the",
+      "content (HTML) on the page.  If you do know JavaScript, you can also use", strong("shinyjs"), "to call",
+      "you own JavaScript functions as if they were R code."),
+    p("As an extra perk, ", strong("shinyjs"), "also includes a ",
+      a(href = "http://daattali.com/shiny/colourInput/", "colourInput() Shiny widget"),
+      "and a", a(href = "https://raw.githubusercontent.com/daattali/shinyjs/master/inst/img/colourPickerGadget.gif",
+                 "colour picker RStudio addin+gadget"), "for selecting colours easily."),
     shiny::hr(),
     h3("Examples to try", class = "section-title"),
     p("Click on any of the examples below to quickly copy them into the box on the left,",
